@@ -7,9 +7,8 @@ This module contains methods for launching Rockets, both singly and in rapid-fir
 import os
 import time
 from fireworks.core.fw_config import FWConfig
-from fireworks.core.fworker import FWorker
 from fireworks.core.rocket import Rocket
-from fireworks.utilities.fw_utilities import get_fw_logger, create_datestamp_dir
+from fireworks.utilities.fw_utilities import get_fw_logger, create_datestamp_dir, acquire_db_lock, release_db_lock, log_multi
 
 __author__ = 'Anubhav Jain'
 __copyright__ = 'Copyright 2013, The Materials Project'
@@ -27,12 +26,12 @@ def launch_rocket(launchpad, fworker, fw_id=None, strm_lvl='INFO'):
     :param fw_id: (int) if set, a particular FireWork to run
     :param strm_lvl: (str) level at which to output logs to stdout
     """
-    l_logger = get_fw_logger('rocket.launcher', l_dir=launchpad.logdir, stream_level=strm_lvl)
+    l_logger = get_fw_logger('rocket.launcher', l_dir=launchpad.get_logdir(), stream_level=strm_lvl)
 
-    l_logger.info('Launching Rocket')
+    log_multi(l_logger, 'Launching Rocket')
     rocket = Rocket(launchpad, fworker, fw_id)
     rocket.run()
-    l_logger.info('Rocket finished')
+    log_multi(l_logger, 'Rocket finished')
 
 
 def rapidfire(launchpad, fworker, m_dir=None, nlaunches=0, max_loops=-1, sleep_time=None, strm_lvl='INFO'):
@@ -51,24 +50,28 @@ def rapidfire(launchpad, fworker, m_dir=None, nlaunches=0, max_loops=-1, sleep_t
 
     sleep_time = sleep_time if sleep_time else FWConfig().RAPIDFIRE_SLEEP_SECS
     curdir = m_dir if m_dir else os.getcwd()
-    l_logger = get_fw_logger('rocket.launcher', l_dir=launchpad.logdir, stream_level=strm_lvl)
+    l_logger = get_fw_logger('rocket.launcher', l_dir=launchpad.get_logdir(), stream_level=strm_lvl)
     nlaunches = -1 if nlaunches == 'infinite' else int(nlaunches)
 
     num_launched = 0
     num_loops = 0
+
     while num_loops != max_loops:
+        acquire_db_lock()
         while launchpad.run_exists(fworker):
             os.chdir(curdir)
             launcher_dir = create_datestamp_dir(curdir, l_logger, prefix='launcher_')
             os.chdir(launcher_dir)
-            launch_rocket(launchpad, fworker, strm_lvl=strm_lvl)
+            launch_rocket(launchpad, fworker, strm_lvl=strm_lvl)  # releases lock inside
             num_launched += 1
             if num_launched == nlaunches:
                 break
             time.sleep(0.15)  # add a small amount of buffer breathing time for DB to refresh, etc.
+            acquire_db_lock()
+        release_db_lock(safe=False)  # possible no lock was acquired at this point
         if num_launched == nlaunches or nlaunches == 0:
             break
-        l_logger.info('Sleeping for {} secs'.format(sleep_time))
+        log_multi(l_logger, 'Sleeping for {} secs'.format(sleep_time))
         time.sleep(sleep_time)
         num_loops += 1
-        l_logger.info('Checking for FWs to run...'.format(sleep_time))
\ No newline at end of file
+        log_multi(l_logger, 'Checking for FWs to run...'.format(sleep_time))
\ No newline at end of file
